pub enum Errorwhere
Self: Send,{
Read {
source: IoError,
path: PathBuf,
},
Write {
source: IoError,
path: PathBuf,
},
UnitError {
source: Error,
},
InsufficientRights {
path: PathBuf,
},
SubtypeNotSupported {
sub_type: SensorSubFunctionType,
},
FaultySensor,
DisabledSensor,
CustomVirtual {
source: Box<dyn StdError + Send>,
},
}Expand description
Error which can be returned from interacting with sensors.
Variants
Read
Error reading from sensor.
Write
Error writing to sensor.
UnitError
A UnitError occurred.
InsufficientRights
You have insufficient rights. Try using the read only variant of whatever returned this error.
SubtypeNotSupported
The subfunction you requested is not supported by this sensor.
Fields

sub_type: SensorSubFunctionTypeThe requested subfunction
FaultySensor
The sensor you tried to read from is faulty.
DisabledSensor
The sensor you tried to read from or write to is disabled.
CustomVirtual
A custom virtual sensor returned an error